@@ -1,7 +1,7 @@
 import time
 import slai
 
-from slai.clients.project import get_project_client
+# from slai.clients.project import get_project_client
 from slai_cli import log
 
 
