@@ -1,6 +1,6 @@
 from columnar import columnar
 
-from slai.clients.project import get_project_client
+#from slai.clients.project import get_project_client
 
 from slai_cli import log
 from slai_cli.decorators import requires_slai_project
