@@ -4,7 +4,7 @@ import requests
 
 from pathlib import Path
 from slai.clients.model import get_model_client
-from slai.clients.project import get_project_client
+# from slai.clients.project import get_project_client
 from slai.clients.cli import get_cli_client
 
 from slai_cli import log
