@@ -2,7 +2,7 @@ import time
 
 from pathlib import Path
 from slai.clients.cli import get_cli_client
-from slai.modules.notebook_utils import generate_trainer_from_template, parse_notebook
+# from slai.modules.notebook_utils import generate_trainer_from_template, parse_notebook
 from slai_cli import log
 from slai_cli.init.local_config_helper import LocalConfigHelper
 
