@@ -1,6 +1,6 @@
 import requests
 
-from slai.clients.project import get_project_client
+# from slai.clients.project import get_project_client
 from slai.clients.cli import get_cli_client
 from slai.clients.model import get_model_client
 
