@@ -1,7 +1,7 @@
 import requests
 
 from slai.clients.model import get_model_client
-from slai.clients.project import get_project_client
+# from slai.clients.project import get_project_client
 from slai.clients.cli import get_cli_client
 from slai_cli.init.local_config_helper import LocalConfigHelper
 from slai_cli.modules.docker_client import DockerClient
