@@ -1,4 +1,4 @@
-from slai.clients.gdrive import get_google_drive_client
+# from slai.clients.gdrive import get_google_drive_client
 
 
 class DriveClient:
