@@ -3,7 +3,7 @@ import click
 
 from slai_cli.profile import configure as _configure
 from slai_cli.profile import list as _list
-from slai.modules.runtime import ValidRuntimes
+# from slai.modules.runtime import ValidRuntimes
 
 
 @click.group()
@@ -18,7 +18,6 @@ def profile():
 def configure(profile_name, client_id, client_secret):
     _configure.get_credentials(
         profile_name=profile_name,
-        runtime=ValidRuntimes.Local,
         client_id=client_id,
         client_secret=client_secret,
     )
