@@ -7,17 +7,15 @@ import sys
 from pathlib import Path
 from slai_cli import log
 from slai_cli.exceptions import InvalidApiKey
-from slai.modules.runtime import ValidRuntimes
+# from slai.modules.runtime import ValidRuntimes
 
 
 def get_credentials(
     profile_name="default",
-    runtime=ValidRuntimes.Project,
+    #runtime=ValidRuntimes.Project,
     client_id=None,
     client_secret=None,
 ):
-    if runtime == ValidRuntimes.Local:
-        log.action(f"Configuring profile: {profile_name}")
 
     if client_id is None or client_secret is None:
         client_id = click.prompt("Client ID", type=str, default=client_id)
@@ -27,8 +25,7 @@ def get_credentials(
         store_credentials(
             profile_name=profile_name,
             client_id=client_id,
-            client_secret=client_secret,
-            runtime=runtime,
+            client_secret=client_secret
         )
     except InvalidApiKey:
         log.warn("Invalid credentials.")
@@ -37,7 +34,7 @@ def get_credentials(
     log.action("Credentials configured.")
 
 
-def store_credentials(*, profile_name, client_id, client_secret, runtime):
+def store_credentials(*, profile_name, client_id, client_secret):
     new_profile = {
         "client_id": client_id,
         "client_secret": client_secret,
@@ -49,12 +46,9 @@ def store_credentials(*, profile_name, client_id, client_secret, runtime):
         log.warn("Invalid credentials")
         sys.exit(1)
 
-    if runtime == ValidRuntimes.Local:
-        credentials_path = f"{Path.home()}/.slai"
-        if not os.path.exists(credentials_path):
-            os.makedirs(credentials_path)
-    elif runtime == ValidRuntimes.Project:
-        credentials_path = f"{Path.cwd()}/.slai"
+    credentials_path = f"{Path.home()}/.slai"
+    if not os.path.exists(credentials_path):
+        os.makedirs(credentials_path)
 
     try:
         with open(f"{credentials_path}/credentials.yml", "r") as f_in:
@@ -66,13 +60,10 @@ def store_credentials(*, profile_name, client_id, client_secret, runtime):
         credentials = {}
 
     # save new profile
-    if runtime == ValidRuntimes.Local:
-        if credentials.get("default") is None:
-            credentials["default"] = new_profile
+    if credentials.get("default") is None:
+        credentials["default"] = new_profile
 
-        credentials[profile_name] = new_profile
-    elif runtime == ValidRuntimes.Project:
-        credentials = new_profile
+    credentials[profile_name] = new_profile
 
     noalias_dumper = yaml.dumper.SafeDumper
     noalias_dumper.ignore_aliases = lambda self, data: True
